import request from "@/helpers/request";
import { Icon, Toast, Uploader, Image } from "vant";
import { defineComponent } from "vue";
import styles from "./index.module.less";

import iconUploader from '@common/images/icon_uploader_video.png';

export default defineComponent({
  name: "ColUploadVideo",
  props: {
    modelValue: String,
    tips: {
      type: String,
      default: '点击上传'
    },
    size: {
      type: Number,
      default: 30
    },
    deletable: {
      type: Boolean,
      default: true
    }
  },
  methods: {
    beforeRead(file: any) {
      const isLt2M = file.size / 1024 / 1024 < this.size
      console.log(this.size)
      if (!isLt2M) {
        Toast(`上传视屏大小不能超过 ${this.size}MB`)
        return false
      }
      return true
    },
    beforeDelete(file: any, detail: { index: any; }) {
      // this.dataModel.splice(detail.index, 1)
      return true
    },
    async afterRead(file: any, detail: any) {
      try {
        file.status = 'uploading';
        file.message = '上传中...';
        let formData = new FormData();
        formData.append('file', file.file);
        let res = await request.post('/api-teacher/uploadFile', {
          data: formData
        })
        this.$emit('update:modelValue', res.data.url);
      } catch (error) {
        //
      }
    },
    onClose(e: any) {
      this.$emit('update:modelValue', null);
      e.stopPropagation();
    },
  },
  render() {
    return (
      <div class={styles['uploader-section']}>
          {/* @ts-ignore */}
          <Uploader accept=".mp4" afterRead={this.afterRead} beforeRead={this.beforeRead} beforeDelete={this.beforeDelete}
            v-slots={{
              default: () => (this.modelValue ? <Image fit="cover" position="center" class={styles.uploadImg} src={this.modelValue} /> : <div class={styles.uploader}>
                <Icon name={iconUploader} size="32" />
                <p class={styles.uploaderText}>{this.tips}</p>
              </div>)
            }}
          />
      </div>
    )
  }
})