import ColField from "@/components/col-field";
import ColFieldGroup from "@/components/col-field-group";
import ColUpload from "@/components/col-upload";
import ColUploadVideo from "@/components/col-upload-video";
import { Button, Col, Dialog, Field, Icon, Row, Sticky } from "vant";
import { defineComponent } from "vue";
import styles from './class-content.module.less';

export default defineComponent({
  name: "ClassContent",
  data() {
    return {
      dataList: [1]
    }
  },
  methods: {
    addItem() {
      this.dataList.push(this.dataList.length + 1)
    },
    removeItem(index: number) {
      // 最少一节课
      if(this.dataList.length <= 1) return
      Dialog.confirm({
        title: '操作',
        message: `确定删除该条数据吗？`,
        confirmButtonColor: '#2DC7AA',
      })
      .then(() => {
        // on confirm
        this.dataList.splice(index, 1)
      })
    }
  },
  render() {
    return (
      <div class={styles['class-content']}>
        {this.dataList.map((item: any, index: number) => (
          <>
            <div class={styles.titleSection}>
              <span class={styles.title}>第{ index + 1 }课</span>
              <Icon name="delete-o" class={this.dataList.length <= 1 ? styles.disabled : null} onClick={() => this.removeItem(index)} size={20} />
            </div>
            <ColFieldGroup>
              <ColField title="课程标题" required>
                <Field
                  name="课程标题"
                  placeholder="请输入您的课程标题"
                />
              </ColField>
              <ColField title="课程内容" required>
                <Field
                  name="课程内容"
                  placeholder="请输入您的课程内容"
                />
              </ColField>
              <ColField title="课程视频及视频封面" required border={false}>
                <Row justify="space-between" style={{ width: '100%', paddingTop: '12px' }}>
                  <Col span={12}>
                    <ColUploadVideo class={styles.upload} tips="点击上传视屏" />
                  </Col>
                  <Col span={12}>
                    <ColUpload class={styles.upload} tips="点击上传视频封面" />
                  </Col>
                </Row>
              </ColField>
            </ColFieldGroup>
          </>
        ))}

        <Button class={styles['add-item']} block icon="add-o" onClick={this.addItem}>添加课程</Button>

        <Sticky offsetBottom={0} position="bottom">
            <div class={[styles.btnGroup, styles.btnMore]}>
              <Button block round type="primary" plain>上一步</Button>
              <Button block round type="primary">提交</Button>
            </div>
          </Sticky>
      </div>
    )
  }
})